@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.BusinessParams import BusinessParams
 from alipay.aop.api.domain.ExtUserInfo import ExtUserInfo
 from alipay.aop.api.domain.ExtendParams import ExtendParams
 from alipay.aop.api.domain.GoodsDetail import GoodsDetail
@@ -31,6 +32,8 @@ class AlipayTradeCreateModel(object):
         self._merchant_order_no = None
         self._operator_id = None
         self._out_trade_no = None
+        self._passback_params = None
+        self._product_code = None
         self._receiver_address_info = None
         self._royalty_info = None
         self._seller_id = None
@@ -63,7 +66,10 @@ class AlipayTradeCreateModel(object):
 
     @business_params.setter
     def business_params(self, value):
-        self._business_params = value
+        if isinstance(value, BusinessParams):
+            self._business_params = value
+        else:
+            self._business_params = BusinessParams.from_alipay_dict(value)
     @property
     def buyer_id(self):
         return self._buyer_id
@@ -164,6 +170,20 @@ class AlipayTradeCreateModel(object):
     def out_trade_no(self, value):
         self._out_trade_no = value
     @property
+    def passback_params(self):
+        return self._passback_params
+
+    @passback_params.setter
+    def passback_params(self, value):
+        self._passback_params = value
+    @property
+    def product_code(self):
+        return self._product_code
+
+    @product_code.setter
+    def product_code(self, value):
+        self._product_code = value
+    @property
     def receiver_address_info(self):
         return self._receiver_address_info
 
@@ -336,6 +356,16 @@ class AlipayTradeCreateModel(object):
                 params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
             else:
                 params['out_trade_no'] = self.out_trade_no
+        if self.passback_params:
+            if hasattr(self.passback_params, 'to_alipay_dict'):
+                params['passback_params'] = self.passback_params.to_alipay_dict()
+            else:
+                params['passback_params'] = self.passback_params
+        if self.product_code:
+            if hasattr(self.product_code, 'to_alipay_dict'):
+                params['product_code'] = self.product_code.to_alipay_dict()
+            else:
+                params['product_code'] = self.product_code
         if self.receiver_address_info:
             if hasattr(self.receiver_address_info, 'to_alipay_dict'):
                 params['receiver_address_info'] = self.receiver_address_info.to_alipay_dict()
@@ -428,6 +458,10 @@ class AlipayTradeCreateModel(object):
             o.operator_id = d['operator_id']
         if 'out_trade_no' in d:
             o.out_trade_no = d['out_trade_no']
+        if 'passback_params' in d:
+            o.passback_params = d['passback_params']
+        if 'product_code' in d:
+            o.product_code = d['product_code']
         if 'receiver_address_info' in d:
             o.receiver_address_info = d['receiver_address_info']
         if 'royalty_info' in d:
