@@ -4,6 +4,8 @@ import json
 
 from alipay.aop.api.response.AlipayResponse import AlipayResponse
 from alipay.aop.api.domain.TradeFundBill import TradeFundBill
+from alipay.aop.api.domain.HbFqPayInfo import HbFqPayInfo
+from alipay.aop.api.domain.TradeSettleInfo import TradeSettleInfo
 from alipay.aop.api.domain.VoucherDetail import VoucherDetail
 
 
@@ -12,14 +14,23 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def __init__(self):
         super(AlipayTradeQueryResponse, self).__init__()
         self._alipay_store_id = None
+        self._alipay_sub_merchant_id = None
         self._auth_trade_pay_mode = None
+        self._body = None
         self._buyer_logon_id = None
         self._buyer_pay_amount = None
         self._buyer_user_id = None
+        self._buyer_user_name = None
         self._buyer_user_type = None
+        self._charge_amount = None
+        self._charge_flags = None
+        self._credit_biz_order_id = None
+        self._credit_pay_mode = None
         self._discount_amount = None
         self._discount_goods_detail = None
+        self._ext_infos = None
         self._fund_bill_list = None
+        self._hb_fq_pay_info = None
         self._industry_sepc_detail = None
         self._invoice_amount = None
         self._mdiscount_amount = None
@@ -29,15 +40,19 @@ class AlipayTradeQueryResponse(AlipayResponse):
         self._pay_currency = None
         self._point_amount = None
         self._receipt_amount = None
+        self._receipt_currency_type = None
         self._send_pay_date = None
         self._settle_amount = None
         self._settle_currency = None
         self._settle_trans_rate = None
+        self._settlement_id = None
         self._store_id = None
         self._store_name = None
+        self._subject = None
         self._terminal_id = None
         self._total_amount = None
         self._trade_no = None
+        self._trade_settle_info = None
         self._trade_status = None
         self._trans_currency = None
         self._trans_pay_rate = None
@@ -51,6 +66,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def alipay_store_id(self, value):
         self._alipay_store_id = value
     @property
+    def alipay_sub_merchant_id(self):
+        return self._alipay_sub_merchant_id
+
+    @alipay_sub_merchant_id.setter
+    def alipay_sub_merchant_id(self, value):
+        self._alipay_sub_merchant_id = value
+    @property
     def auth_trade_pay_mode(self):
         return self._auth_trade_pay_mode
 
@@ -58,6 +80,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def auth_trade_pay_mode(self, value):
         self._auth_trade_pay_mode = value
     @property
+    def body(self):
+        return self._body
+
+    @body.setter
+    def body(self, value):
+        self._body = value
+    @property
     def buyer_logon_id(self):
         return self._buyer_logon_id
 
@@ -79,6 +108,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def buyer_user_id(self, value):
         self._buyer_user_id = value
     @property
+    def buyer_user_name(self):
+        return self._buyer_user_name
+
+    @buyer_user_name.setter
+    def buyer_user_name(self, value):
+        self._buyer_user_name = value
+    @property
     def buyer_user_type(self):
         return self._buyer_user_type
 
@@ -86,6 +122,34 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def buyer_user_type(self, value):
         self._buyer_user_type = value
     @property
+    def charge_amount(self):
+        return self._charge_amount
+
+    @charge_amount.setter
+    def charge_amount(self, value):
+        self._charge_amount = value
+    @property
+    def charge_flags(self):
+        return self._charge_flags
+
+    @charge_flags.setter
+    def charge_flags(self, value):
+        self._charge_flags = value
+    @property
+    def credit_biz_order_id(self):
+        return self._credit_biz_order_id
+
+    @credit_biz_order_id.setter
+    def credit_biz_order_id(self, value):
+        self._credit_biz_order_id = value
+    @property
+    def credit_pay_mode(self):
+        return self._credit_pay_mode
+
+    @credit_pay_mode.setter
+    def credit_pay_mode(self, value):
+        self._credit_pay_mode = value
+    @property
     def discount_amount(self):
         return self._discount_amount
 
@@ -100,6 +164,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def discount_goods_detail(self, value):
         self._discount_goods_detail = value
     @property
+    def ext_infos(self):
+        return self._ext_infos
+
+    @ext_infos.setter
+    def ext_infos(self, value):
+        self._ext_infos = value
+    @property
     def fund_bill_list(self):
         return self._fund_bill_list
 
@@ -113,6 +184,16 @@ class AlipayTradeQueryResponse(AlipayResponse):
                 else:
                     self._fund_bill_list.append(TradeFundBill.from_alipay_dict(i))
     @property
+    def hb_fq_pay_info(self):
+        return self._hb_fq_pay_info
+
+    @hb_fq_pay_info.setter
+    def hb_fq_pay_info(self, value):
+        if isinstance(value, HbFqPayInfo):
+            self._hb_fq_pay_info = value
+        else:
+            self._hb_fq_pay_info = HbFqPayInfo.from_alipay_dict(value)
+    @property
     def industry_sepc_detail(self):
         return self._industry_sepc_detail
 
@@ -176,6 +257,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def receipt_amount(self, value):
         self._receipt_amount = value
     @property
+    def receipt_currency_type(self):
+        return self._receipt_currency_type
+
+    @receipt_currency_type.setter
+    def receipt_currency_type(self, value):
+        self._receipt_currency_type = value
+    @property
     def send_pay_date(self):
         return self._send_pay_date
 
@@ -204,6 +292,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def settle_trans_rate(self, value):
         self._settle_trans_rate = value
     @property
+    def settlement_id(self):
+        return self._settlement_id
+
+    @settlement_id.setter
+    def settlement_id(self, value):
+        self._settlement_id = value
+    @property
     def store_id(self):
         return self._store_id
 
@@ -218,6 +313,13 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def store_name(self, value):
         self._store_name = value
     @property
+    def subject(self):
+        return self._subject
+
+    @subject.setter
+    def subject(self, value):
+        self._subject = value
+    @property
     def terminal_id(self):
         return self._terminal_id
 
@@ -239,6 +341,16 @@ class AlipayTradeQueryResponse(AlipayResponse):
     def trade_no(self, value):
         self._trade_no = value
     @property
+    def trade_settle_info(self):
+        return self._trade_settle_info
+
+    @trade_settle_info.setter
+    def trade_settle_info(self, value):
+        if isinstance(value, TradeSettleInfo):
+            self._trade_settle_info = value
+        else:
+            self._trade_settle_info = TradeSettleInfo.from_alipay_dict(value)
+    @property
     def trade_status(self):
         return self._trade_status
 
@@ -277,22 +389,40 @@ class AlipayTradeQueryResponse(AlipayResponse):
         response = super(AlipayTradeQueryResponse, self).parse_response_content(response_content)
         if 'alipay_store_id' in response:
             self.alipay_store_id = response['alipay_store_id']
+        if 'alipay_sub_merchant_id' in response:
+            self.alipay_sub_merchant_id = response['alipay_sub_merchant_id']
         if 'auth_trade_pay_mode' in response:
             self.auth_trade_pay_mode = response['auth_trade_pay_mode']
+        if 'body' in response:
+            self.body = response['body']
         if 'buyer_logon_id' in response:
             self.buyer_logon_id = response['buyer_logon_id']
         if 'buyer_pay_amount' in response:
             self.buyer_pay_amount = response['buyer_pay_amount']
         if 'buyer_user_id' in response:
             self.buyer_user_id = response['buyer_user_id']
+        if 'buyer_user_name' in response:
+            self.buyer_user_name = response['buyer_user_name']
         if 'buyer_user_type' in response:
             self.buyer_user_type = response['buyer_user_type']
+        if 'charge_amount' in response:
+            self.charge_amount = response['charge_amount']
+        if 'charge_flags' in response:
+            self.charge_flags = response['charge_flags']
+        if 'credit_biz_order_id' in response:
+            self.credit_biz_order_id = response['credit_biz_order_id']
+        if 'credit_pay_mode' in response:
+            self.credit_pay_mode = response['credit_pay_mode']
         if 'discount_amount' in response:
             self.discount_amount = response['discount_amount']
         if 'discount_goods_detail' in response:
             self.discount_goods_detail = response['discount_goods_detail']
+        if 'ext_infos' in response:
+            self.ext_infos = response['ext_infos']
         if 'fund_bill_list' in response:
             self.fund_bill_list = response['fund_bill_list']
+        if 'hb_fq_pay_info' in response:
+            self.hb_fq_pay_info = response['hb_fq_pay_info']
         if 'industry_sepc_detail' in response:
             self.industry_sepc_detail = response['industry_sepc_detail']
         if 'invoice_amount' in response:
@@ -311,6 +441,8 @@ class AlipayTradeQueryResponse(AlipayResponse):
             self.point_amount = response['point_amount']
         if 'receipt_amount' in response:
             self.receipt_amount = response['receipt_amount']
+        if 'receipt_currency_type' in response:
+            self.receipt_currency_type = response['receipt_currency_type']
         if 'send_pay_date' in response:
             self.send_pay_date = response['send_pay_date']
         if 'settle_amount' in response:
@@ -319,16 +451,22 @@ class AlipayTradeQueryResponse(AlipayResponse):
             self.settle_currency = response['settle_currency']
         if 'settle_trans_rate' in response:
             self.settle_trans_rate = response['settle_trans_rate']
+        if 'settlement_id' in response:
+            self.settlement_id = response['settlement_id']
         if 'store_id' in response:
             self.store_id = response['store_id']
         if 'store_name' in response:
             self.store_name = response['store_name']
+        if 'subject' in response:
+            self.subject = response['subject']
         if 'terminal_id' in response:
             self.terminal_id = response['terminal_id']
         if 'total_amount' in response:
             self.total_amount = response['total_amount']
         if 'trade_no' in response:
             self.trade_no = response['trade_no']
+        if 'trade_settle_info' in response:
+            self.trade_settle_info = response['trade_settle_info']
         if 'trade_status' in response:
             self.trade_status = response['trade_status']
         if 'trans_currency' in response:
